function LayuiInputTree(layui) {
    var $ = layui.$;
    var layer = layui.layer;
    var ztree = layui.ztree;
    var restAjax = layui.restajax;
    var zIndex = 10000;
    // 样式
    var style = `
    <link rel="stylesheet" href="assets/js/vendor/zTree3/css/metroStyle/metroStyle.css"/>
    <style id="layuiInputTreeStyle">
    .layui-input-tree-box {border: 1px solid #e6e6e6; background-color: #FFF; position: absolute; z-index: 1100; display: none;}
    .layui-input-tree-box .ztree-box {width: 140px; height: 160px;overflow: auto;}
    .layui-input-tree-box .ztree-buttons {padding: 0 10px 10px 10px; }
    </style>    
    `
    // 添加样式
    $(document.head).append(style);

    /**
     * 初始化单选
     * @param opt
     */
    this.initSelect = function (opt) {
        var url = opt.url;
        if (!url) {
            return;
        }
        var getSelectedData = opt.getSelectedData;
        var onConfirm = opt.onConfirm;
        var onClear = opt.onClear;
        var defaultParams = opt.defaultParams;
        var key = opt.key;
        var id = opt.id;
        var inputDomId = '#' + id;
        var zTree;
        var selectedData;
        var boxDomId = inputDomId + 'Box';
        var zTreeBoxId = inputDomId + 'ZTreeBox';
        var confirmBtnId = inputDomId + 'ConfirmBtn';
        var clearBtnId = inputDomId + 'ClearBtn';
        var inputDom = $(inputDomId);
        var inputParentDom = inputDom.parent();
        var selectedNode = null;
        inputParentDom.css('position', 'relative');
        inputDom.attr('readonly', '');
        inputDom.css('cursor', 'pointer');
        inputDom.after(`
            <div id="${id}Box" class="layui-input-tree-box">
                <div id="${id}ZTreeBox" class="ztree-box ztree"></div>
                <div class="ztree-buttons">
                    <div class="layui-btn-group">
                        <button id="${id}ConfirmBtn" type="button" class="layui-col-xs6 layui-btn layui-btn-xs" title="确定"><i class="fa fa-check" aria-hidden="true"></i></button>
                        <button id="${id}ClearBtn" type="button" class="layui-col-xs6 layui-btn layui-btn-xs layui-btn-danger" title="清空"><i class="fa fa-trash" aria-hidden="true"></i></button>
                    </div>
                </div>
            </div>
        `);

        // 初始化事件
        function initEvent() {
            $(document).on('click', inputDomId, function () {
                var boxDom = $(boxDomId);
                if (boxDom.is(':hidden')) {
                    boxDom.show();
                    boxDom.css('z-index', zIndex++)
                    if (getSelectedData) {
                        selectedData = getSelectedData();
                    }
                } else {
                    boxDom.hide();
                    // 还原选择
                    if (selectedData) {
                        $(inputDomId).val(selectedData.name);
                    } else {
                        $(inputDomId).val('');
                    }
                }
            })
            // 确认事件
            $(document).on('click', confirmBtnId, function () {
                if (onConfirm) {
                    onConfirm(zTree, selectedNode)
                    $(boxDomId).hide();
                }
            })
            // 清空事件
            $(document).on('click', clearBtnId, function () {
                selectedNode = null;
                $(inputDomId).val('');
                zTree.cancelSelectedNode();
                if (onClear) {
                    onClear(zTree);
                    $(boxDomId).hide();
                }
            })
        }

        // 初始化zTree
        function initZTree() {
            var setting = {
                async: {
                    enable: true,
                    autoLoad: true,
                    type: 'get',
                    url: url,
                    autoParam: ['id'],
                    otherParam: defaultParams ? defaultParams : {},
                    dataFilter: function (treeId, parentNode, childNodes) {
                        if (!childNodes) return null;
                        $.each(childNodes, function (index, item) {
                            asyncDataFilter(key, item);
                        });
                        return childNodes;
                    }
                },
                callback: {
                    onClick: function (event, treeId, treeNode) {
                        selectedNode = treeNode;
                        $(inputDomId).val(treeNode.name);
                        return false;
                    }
                }
            }
            zTree = $.fn.zTree.init($(zTreeBoxId), setting);
        }

        initZTree();
        initEvent();
    }


    /**
     * 初始化多选
     * @param opt
     */
    this.initMultiSelect = function (opt) {
        var url = opt.url;
        if (!url) {
            return;
        }
        var getSelectedDatas = opt.getSelectedDatas;
        var onConfirm = opt.onConfirm;
        var onClear = opt.onClear;
        var checkboxType = opt.checkboxType;
        var defaultParams = opt.defaultParams;
        var id = opt.id;
        var key = opt.key;
        var inputDomId = '#' + id;
        var zTree;
        var selectedDatas;
        var selectedNodesObj = {};
        var boxDomId = inputDomId + 'Box';
        var zTreeBoxId = inputDomId + 'ZTreeBox';
        var confirmBtnId = inputDomId + 'ConfirmBtn';
        var clearBtnId = inputDomId + 'ClearBtn';
        var inputDom = $(inputDomId);
        var inputParentDom = inputDom.parent();
        inputParentDom.css('position', 'relative');
        inputDom.attr('readonly', '');
        inputDom.css('cursor', 'pointer');
        inputDom.after(`
            <div id="${id}Box" class="layui-input-tree-box">
                <div id="${id}ZTreeBox" class="ztree-box ztree"></div>
                <div class="ztree-buttons">
                    <div class="layui-btn-group">
                        <button id="${id}ConfirmBtn" type="button" class="layui-col-xs6 layui-btn layui-btn-xs" title="确定"><i class="fa fa-check" aria-hidden="true"></i></button>
                        <button id="${id}ClearBtn" type="button" class="layui-col-xs6 layui-btn layui-btn-xs layui-btn-danger" title="清空"><i class="fa fa-trash" aria-hidden="true"></i></button>
                    </div>
                </div>
            </div>
        `);

        /**
         * 勾选节点
         * @param id
         */
        function checkNode(id) {
            var node = zTree.getNodeByParam('id', id);
            if (!node) {
                return;
            }
            zTree.checkNode(node, true, true);
        }

        /**
         * 输入框显示
         */
        function boxDomShow() {
            if (!getSelectedDatas) {
                return;
            }
            selectedDatas = getSelectedDatas();
            if (!selectedDatas || selectedDatas.length == 0) {
                return;
            }
            $.each(selectedDatas, function (index, item) {
                selectedNodesObj[item.id] = item;
                // 勾选节点
                checkNode(item.id);
            })
        }

        /**
         * 输入框隐藏
         */
        function boxHide() {
            // 还原原有选择
            if (selectedDatas && selectedDatas.length > 0) {
                var names = '';
                $.each(selectedDatas, function (index, item) {
                    if (names != '') {
                        names += ',';
                    }
                    names += item.name;
                })
                $(inputDomId).val(names);
            } else {
                $(inputDomId).val('');
            }
            // 取消所有勾选状态
            var checkedNodes = zTree.getCheckedNodes();
            $.each(checkedNodes, function (index, item) {
                zTree.checkNode(item, false);
            });
        }

        // 初始化事件
        function initEvent() {
            $(document).on('click', inputDomId, function () {
                var boxDom = $(boxDomId);
                if (boxDom.is(':hidden')) {
                    boxDom.css('z-index', zIndex++)
                    boxDom.show();
                    boxDomShow();
                } else {
                    selectedNodesObj = {};
                    boxDom.hide();
                    boxHide();
                }
            })
            // 确认事件
            $(document).on('click', confirmBtnId, function () {
                if (onConfirm) {
                    var selectedNodes = [];
                    for (var key in selectedNodesObj) {
                        selectedNodes.push(selectedNodesObj[key]);
                    }
                    onConfirm(zTree, selectedNodes)
                    $(boxDomId).hide();
                }
            })
            // 清空事件
            $(document).on('click', clearBtnId, function () {
                selectedNodesObj = {};
                $(inputDomId).val('');
                zTree.checkAllNodes(false);
                if (onClear) {
                    onClear(zTree);
                    $(boxDomId).hide();
                }
            })
        }

        // 初始化zTree
        function initZTree() {
            var setting = {
                async: {
                    enable: true,
                    autoLoad: true,
                    type: 'get',
                    url: url,
                    autoParam: ['id'],
                    otherParam: defaultParams ? defaultParams : {},
                    dataFilter: function (treeId, parentNode, childNodes) {
                        if (!childNodes) return null;
                        $.each(childNodes, function (index, item) {
                            asyncDataFilter(key, item);
                        });
                        return childNodes;
                    }
                },
                check: {
                    enable: true,
                    chkboxType: checkboxType ? checkboxType : {'Y': 'ps', 'N': 'ps'},
                    chkStyle: 'checkbox'
                },
                callback: {
                    onAsyncSuccess: function (event, treeId, treeNode) {
                        // 加载完默认勾选
                        for (var key in selectedNodesObj) {
                            checkNode(key);
                        }
                    },
                    onCheck: function (event, treeId, treeNode) {
                        if (treeNode.checked) {
                            selectedNodesObj[treeNode.id] = treeNode;
                        } else {
                            delete selectedNodesObj[treeNode.id];
                        }
                        var names = '';
                        for (var key in selectedNodesObj) {
                            if (names != '') {
                                names += ',';
                            }
                            names += selectedNodesObj[key].name;
                        }
                        $(inputDomId).val(names);
                        return false;
                    }
                }
            }
            zTree = $.fn.zTree.init($(zTreeBoxId), setting);
        }

        initZTree();
        initEvent();
    }

    /**
     * 异步数据过滤
     * @param key
     * @param item
     */
    function asyncDataFilter(key, item) {
        if (key) {
            item.id = item[key.id] ? item[key.id] : item.id;
            item.name = item[key.name] ? item[key.name].replace(/\.n/g, '.') : item.name;
            item.title = item[key.title] ? item[key.title] : item.title;
            item.pId = item[key.pId] ? item[key.pId] : item.pId;
            item.checked = item[key.checked] ? item[key.checked] : item.checked;
            item.children = item[key.children] ? item[key.children] : item.children;
            item.isParent = item[key.isParent] ? item[key.isParent] : item.isParent;
            item.isHidden = item[key.isHidden] ? item[key.isHidden] : item.isHidden;
            item.url = item[key.url] ? item[key.url] : item.url;
        } else {
            item.name = item.name.replace(/\.n/g, '.');
        }
    }

}