# 下拉选择

## 静态

### 表单

```html

<div class="layui-form-item">
    <label class="layui-form-label"></label>
    <div class="layui-input-block">
        <select id="selector" name="selector" lay-filter="selectorSelect">
            <option value="">选择类型</option>
            <option value="type1">类型1</option>
            <option value="type2">类型2</option>
        </select>
    </div>
</div>
```

### 列表搜索

```html

<div class="layui-inline layui-form search-item">
    <select id="type" name="type" lay-filter="typeFilter">
        <option value="">选择类型</option>
        <option value="type1">类型1</option>
        <option value="type2">类型2</option>
    </select>
</div>
```

## 动态

js

```js
<script src="assets/js/common/layui-select.js"></script>
```

初始化

```js
var layuiSelect = new LayuiSelect(layui);
```

### 单下拉

#### 通用

html

```html

<div class="layui-form-item">
    <label class="layui-form-label">最高学历</label>
    <input type="hidden" id="xxxName" name="xxxName">
    <div class="layui-input-block" id="xxxIdBox"></div>
</div>
```

js

```js
layuiSelect.select({
    url: top.restAjax.path('', []),
    domId: 'xxxIdBox',
    name: 'xxxId',
    required: true,
    dataForm: 'dataForm',
    valueKey: 'dataId',
    nameKey: 'dataName',
    onSelect: function (data, option) {
        var optionValue = option.value;
        var optionText = option.innerText;
    }
});
```

> xxx为需要替换的名称

#### 数据字典

js

```js
layuiSelect.selectData({
    parentId: '',
    domId: 'xxxIdBox',
    name: 'xxxId',
    required: true,
    dataForm: 'dataForm',
    onSelect: function (data, option) {
        $('#xxxName').val(option.innerText);
    }
});
```

参数

|名称| 类型       | 描述                                                       | 是否必填 |
|---|----------|----------------------------------------------------------|------|
|url| string   | 请求地址                                                     | 是    |
|domId| string   | 加载下拉的div                                                 | 是    |
|name| string   | select的ID与NAME属性值                                        | 是    |
|required| boolean  | 是否校验                                                     | 否    |
|dataForm| string   | 表单的lay-filter值                                           | 是    |
|valueKey| string   | 接口返回的数据渲染到option的value属性的值                               | 是    |
|nameKey| string   | 接口返回的数据渲染到option的innerText的值                             | 是    |
|selectedValue| string   | 选中的默认值                                                   | 否    |
|optionDataKeyArray| array    | 需要附带在option上的属性值，取值的时候通过option.dataset.dataX 获取，其中X为数组下标 | 否    |
|onInit| function | 渲染时触发回调                                                  | 否    |
|onSelect| function | 选择时触发回调                                                  | 否    |

事件

onInit：渲染或更新时触发事件

|名称| 类型     | 描述                   |
|---|--------|----------------------|
|selectedValue| string | 选中的默认值，空字符串时，不触发数据加载 |
|option| dom    | 默认选中的option          |

onSelect：选择时触发事件

|名称|类型| 描述                               |
|---|---|----------------------------------|
|data|obj| 选择的option数据，包含原始DOM，美化后的DOM，选中的值 |
|option|dom| 选中的option                        |

### 下拉联动

#### 多级地区联动（示例）

> 树形结构，下拉联动需要配合dom实现

html

```html

<div class="layui-row" style="margin-top: 10px;">
    <span class="search-item-key">户籍地</span>
    <div class="layui-inline layui-form search-item ">
        <select id="registerArea0" name="registerArea0" lay-filter="registerArea0Select"></select>
    </div>
    <div class="layui-inline layui-form search-item ">
        <select id="registerArea1" name="registerArea1" lay-filter="registerArea1Select"></select>
    </div>
    <div class="layui-inline layui-form search-item ">
        <select id="registerArea2" name="registerArea2" lay-filter="registerArea2Select"></select>
    </div>
    <div class="layui-inline layui-form search-item ">
        <select id="registerArea3" name="registerArea3" lay-filter="registerArea3Select"></select>
    </div>
    <div class="layui-inline layui-form search-item ">
        <select id="registerArea4" name="registerArea4" lay-filter="registerArea4Select"></select>
    </div>
</div>
```

`<select>` 的 **id**、**name** 需要相同，下标从**0**开始，**lay-filter** 为 **id** 值 + **Select**。
固定写法，下标递增

```js
layuiSelect.selectLinkageArea({
    baseRootId: 0,
    selectId: 'registerArea',
    optionDataKeyArray: ['areaCode'],
    onSelect: function (data, option, index) {
        var value = data.value;
        // 删除元素
        selectedRegisterAreaArray.splice(index, 5 - index);
        if (value) {
            selectedRegisterAreaArray[index] = option.innerText;
        }
    }
});
```

参数

|名称|类型|描述| 是否必填 |
|---|---|---|------|
|baseRootId|string|第一个下拉框的根节点ID| 是    |
|selectId|string|select的ID（不包含下标）| 是    |
|optionDataKeyArray|array|需要附带在option上的属性值，取值的时候通过option.dataset.dataX 获取，其中X为数组下标| 否    |
|onSelect|function|选择事件| 是    |

事件

onSelect：选择时触发事件

|名称|类型| 描述                               |
|---|---|----------------------------------|
|data|obj| 选择的option数据，包含原始DOM，美化后的DOM，选中的值 |
|option|dom| 选中的option                        |
|index|number| select下标                         |
