package ink.wgink.module.attn.service.signin.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.module.attn.dao.signin.ISignInDao;
import ink.wgink.module.attn.pojo.bos.signin.SignInBO;
import ink.wgink.module.attn.pojo.dtos.signin.SignInDTO;
import ink.wgink.module.attn.pojo.pos.signin.SignInPO;
import ink.wgink.module.attn.pojo.vos.signin.SignInVO;
import ink.wgink.module.attn.service.signin.ISignInService;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.util.UUIDUtil;
import ink.wgink.util.map.HashMapUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: SignInServiceImpl
 * @Description: 考勤签到
 * @Author: CodeFactory
 * @Date: 2022-07-11 15:08:18
 * @Version: 3.0
 **/
@Service
public class SignInServiceImpl extends DefaultBaseService implements ISignInService {

    @Autowired
    private ISignInDao signInDao;

    @Override
    public void save(SignInVO signInVO) {
        saveReturnId(signInVO);
    }

    @Override
    public void save(String token, SignInVO signInVO) {
        saveReturnId(token, signInVO);
    }

    @Override
    public String saveReturnId(SignInVO signInVO) {
        return saveReturnId(null, signInVO);
    }

    @Override
    public String saveReturnId(String token, SignInVO signInVO) {
        String signInId = UUIDUtil.getUUID();
        Map<String, Object> params = HashMapUtil.beanToMap(signInVO);
        params.put("signInId", signInId);
        if (StringUtils.isBlank(token)) {
            setSaveInfo(params);
        } else {
            setAppSaveInfo(token, params);
        }
        signInDao.save(params);
        return signInId;
    }

    @Override
    public void remove(List<String> ids) {
        remove(null, ids);
    }

    @Override
    public void remove(String token, List<String> ids) {
        Map<String, Object> params = getHashMap(2);
        params.put("signInIds", ids);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        signInDao.remove(params);
    }

    @Override
    public void delete(List<String> ids) {
        Map<String, Object> params = getHashMap(2);
        params.put("signInIds", ids);
        signInDao.delete(params);
    }

    @Override
    public void update(String signInId, SignInVO signInVO) {
        update(null, signInId, signInVO);
    }

    @Override
    public void update(String token, String signInId, SignInVO signInVO) {
        Map<String, Object> params = HashMapUtil.beanToMap(signInVO);
        params.put("signInId", signInId);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        signInDao.update(params);
    }

    @Override
    public SignInDTO get(Map<String, Object> params) {
        return signInDao.get(params);
    }

    @Override
    public SignInDTO get(String signInId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signInId", signInId);
        return get(params);
    }

    @Override
    public SignInBO getBO(Map<String, Object> params) {
        return signInDao.getBO(params);
    }

    @Override
    public SignInBO getBO(String signInId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signInId", signInId);
        return getBO(params);
    }

    @Override
    public SignInPO getPO(Map<String, Object> params) {
        return signInDao.getPO(params);
    }

    @Override
    public SignInPO getPO(String signInId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signInId", signInId);
        return getPO(params);
    }

    @Override
    public List<SignInDTO> list(Map<String, Object> params) {
        return signInDao.list(params);
    }

    @Override
    public List<SignInBO> listBO(Map<String, Object> params) {
        return signInDao.listBO(params);
    }

    @Override
    public List<SignInPO> listPO(Map<String, Object> params) {
        return signInDao.listPO(params);
    }

    @Override
    public SuccessResultList<List<SignInDTO>> listPage(ListPage page) {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<SignInDTO> signInDTOs = list(page.getParams());
        PageInfo<SignInDTO> pageInfo = new PageInfo<>(signInDTOs);
        return new SuccessResultList<>(signInDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    @Override
    public Integer count(Map<String, Object> params) {
        Integer count = signInDao.count(params);
        return count == null ? 0 : count;
    }

}