package ink.wgink.module.attn.service.signout.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.module.attn.dao.signout.ISignOutDao;
import ink.wgink.module.attn.pojo.bos.signout.SignOutBO;
import ink.wgink.module.attn.pojo.dtos.signout.SignOutDTO;
import ink.wgink.module.attn.pojo.pos.signout.SignOutPO;
import ink.wgink.module.attn.pojo.vos.signout.SignOutVO;
import ink.wgink.module.attn.service.signout.ISignOutService;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.util.UUIDUtil;
import ink.wgink.util.map.HashMapUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: SignOutServiceImpl
 * @Description: 考勤签退
 * @Author: CodeFactory
 * @Date: 2022-07-11 15:09:12
 * @Version: 3.0
 **/
@Service
public class SignOutServiceImpl extends DefaultBaseService implements ISignOutService {

    @Autowired
    private ISignOutDao signOutDao;

    @Override
    public void save(SignOutVO signOutVO) {
        saveReturnId(signOutVO);
    }

    @Override
    public void save(String token, SignOutVO signOutVO) {
        saveReturnId(token, signOutVO);
    }

    @Override
    public String saveReturnId(SignOutVO signOutVO) {
        return saveReturnId(null, signOutVO);
    }

    @Override
    public String saveReturnId(String token, SignOutVO signOutVO) {
        String signOutId = UUIDUtil.getUUID();
        Map<String, Object> params = HashMapUtil.beanToMap(signOutVO);
        params.put("signOutId", signOutId);
        if (StringUtils.isBlank(token)) {
            setSaveInfo(params);
        } else {
            setAppSaveInfo(token, params);
        }
        signOutDao.save(params);
        return signOutId;
    }

    @Override
    public void remove(List<String> ids) {
        remove(null, ids);
    }

    @Override
    public void remove(String token, List<String> ids) {
        Map<String, Object> params = getHashMap(2);
        params.put("signOutIds", ids);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        signOutDao.remove(params);
    }

    @Override
    public void delete(List<String> ids) {
        Map<String, Object> params = getHashMap(2);
        params.put("signOutIds", ids);
        signOutDao.delete(params);
    }

    @Override
    public void update(String signOutId, SignOutVO signOutVO) {
        update(null, signOutId, signOutVO);
    }

    @Override
    public void update(String token, String signOutId, SignOutVO signOutVO) {
        Map<String, Object> params = HashMapUtil.beanToMap(signOutVO);
        params.put("signOutId", signOutId);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        signOutDao.update(params);
    }

    @Override
    public SignOutDTO get(Map<String, Object> params) {
        return signOutDao.get(params);
    }

    @Override
    public SignOutDTO get(String signOutId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signOutId", signOutId);
        return get(params);
    }

    @Override
    public SignOutBO getBO(Map<String, Object> params) {
        return signOutDao.getBO(params);
    }

    @Override
    public SignOutBO getBO(String signOutId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signOutId", signOutId);
        return getBO(params);
    }

    @Override
    public SignOutPO getPO(Map<String, Object> params) {
        return signOutDao.getPO(params);
    }

    @Override
    public SignOutPO getPO(String signOutId) {
        Map<String, Object> params = super.getHashMap(2);
        params.put("signOutId", signOutId);
        return getPO(params);
    }

    @Override
    public List<SignOutDTO> list(Map<String, Object> params) {
        return signOutDao.list(params);
    }

    @Override
    public List<SignOutBO> listBO(Map<String, Object> params) {
        return signOutDao.listBO(params);
    }

    @Override
    public List<SignOutPO> listPO(Map<String, Object> params) {
        return signOutDao.listPO(params);
    }

    @Override
    public SuccessResultList<List<SignOutDTO>> listPage(ListPage page) {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<SignOutDTO> signOutDTOs = list(page.getParams());
        PageInfo<SignOutDTO> pageInfo = new PageInfo<>(signOutDTOs);
        return new SuccessResultList<>(signOutDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    @Override
    public Integer count(Map<String, Object> params) {
        Integer count = signOutDao.count(params);
        return count == null ? 0 : count;
    }

}